@@ -16,6 +16,7 @@ the use case is correct.
 
 static int log_level=J_LOG_NONE; //Default.
 static FILE *log_file = NULL;
+static gboolean also_to_stdout = FALSE; //Write to file AND to STDOUT
 
 void cem_set_log_level(int new_level) {
 	log_level=new_level;
@@ -34,6 +35,9 @@ void cem_append_to_log_level(int level){
 	g_free(message);
 }
 
+void cem_print_also_to_stdout(gboolean b) {
+	also_to_stdout=b;
+}
 
 static gchar* type_to_word(int type) {
 GString* string = g_string_new("");
@@ -147,12 +151,15 @@ void cem_add_to_log(char *message,int type){
 
 		gchar* final = g_strdup_printf("[%s] %s: \"%s\"\n",SMPTE_timestamp, name,message);
 
+		//If user explicitely wants to print to STDOUT. Or if there are something wrong with log_file.
+		if (also_to_stdout || !log_file){
+			printf("%s",final);
+		}
+		//Write to log_file if file is working.
 		if (log_file) {
 			fprintf(log_file,"%s",final);
 			fflush(log_file);
 		}
-		//else  //Currently we want them to STDOUT too
-			printf("%s",final);
 
 		g_free(name);
 		g_free(final);
