@@ -20,8 +20,8 @@ void quitconfirmation_quit_confirmed(TangleAction *action, GObject *source, cons
 
 void quitconfirmation_mentor_action(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	//Hide mentor (withoud hiding)
-	jammo_mentor_set_active_scale(jammo_mentor_get_default(),0.0001);
-	jammo_mentor_set_standby_scale(jammo_mentor_get_default(),0.0001);
+	clutter_actor_set_width(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);
+	clutter_actor_set_height(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);
 
 	jammo_mentor_speak(jammo_mentor_get_default(), "quit_confirmation.spx");
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "quit_confirmation.spx");
@@ -29,8 +29,8 @@ void quitconfirmation_mentor_action(TangleAction *action, GObject *source, const
 
 void quitconfirmation_cancel_action (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	cem_add_to_log("Quit canceled", J_LOG_USER_ACTION);
-	jammo_mentor_set_active_scale(jammo_mentor_get_default(),1.0);
-	jammo_mentor_set_standby_scale(jammo_mentor_get_default(),0.25);
+	clutter_actor_set_width(CLUTTER_ACTOR(jammo_mentor_get_default()),309);
+	clutter_actor_set_height(CLUTTER_ACTOR(jammo_mentor_get_default()),480);
 
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "main_menu_idle.spx");
 	tangle_action_execute(TANGLE_ACTION(jammo_get_object_by_id("quitconfirmation-cancel-action2")));
