@@ -261,15 +261,6 @@ void singinggame_force_reinit_songs(){
 	initialization_needed = TRUE;
 }
 
-static void say_this_too(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer data){
-	if (interrupted){
-	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
-	}
-	else {
-		jammo_mentor_speak(jammo_mentor_get_default(),(gchar*)data);
-	}
-}
-
 
 /*
 This funtion is called when songselection-view is showed (animation stopped).
@@ -448,9 +439,9 @@ void singinggame_start_songselection(){
 		}
 
 	if (chum_get_duetto())
-		jammo_mentor_set_idle_speech_with_callback(jammo_mentor_get_default(),"songselection_idle.spx",say_this_too,"songselection_idle_vocal.spx");
+		jammo_mentor_set_idle_speech(jammo_mentor_get_default(),"songselection_idle.spx songselection_idle_vocal.spx");
 	else
-		jammo_mentor_set_idle_speech_with_callback(jammo_mentor_get_default(),"songselection_idle.spx",say_this_too,"songselection_idle_instrument.spx");
+		jammo_mentor_set_idle_speech(jammo_mentor_get_default(),"songselection_idle.spx songselection_idle_instrument.spx");
 
 	initialization_needed=FALSE;
 }
