@@ -67,17 +67,20 @@ void start_avatar_editor(){
 		hobbiesTextField.text = jammo_get_actor_by_id("avatar_hobbies_textfield");
 		clutter_text_set_text(CLUTTER_TEXT(hobbiesTextField.text), _("<<YOUR HOBBIES HERE>>"));
 		hobbiesTextField.lineCount = 2;
+		hobbiesTextField.max_characters = 500;
 		hobbiesTextField.handler_id = g_signal_connect_swapped(hobbiesTextField.text, "text-changed", (GCallback)limit_line_count, &hobbiesTextField);
  
 		
 		nameTextField.text = jammo_get_actor_by_id("avatar_name_textfield");
 		clutter_text_set_text(CLUTTER_TEXT(nameTextField.text), _("<<YOUR NAME HERE>>"));
 		nameTextField.lineCount = 1;
+		nameTextField.max_characters = 500;
 		nameTextField.handler_id = g_signal_connect_swapped(nameTextField.text, "text-changed", (GCallback)limit_line_count, &nameTextField);		
 		
 		genderTextField.text = jammo_get_actor_by_id("avatar_gender_textfield");
 		clutter_text_set_text(CLUTTER_TEXT(genderTextField.text), _("<<YOUR GENDER HERE>>"));
 		genderTextField.lineCount = 1;
+		genderTextField.max_characters = 500;
 		genderTextField.handler_id = g_signal_connect_swapped(genderTextField.text, "text-changed", (GCallback)limit_line_count, &genderTextField);					
 	
 		avatar_id = gems_profile_manager_get_avatar_id(NULL);
