@@ -30,7 +30,7 @@ GList *labelParamsList = 0;
 
 void start_jammosongs(){
 
-	int numberOfSongs = 6;  //this should contain the number of songs in the list
+	int numberOfSongs = 0;  //this should contain the number of songs in the list
 
 	printf("Starting JamMoSongs\n");
 	
@@ -56,7 +56,7 @@ void start_jammosongs(){
 
 
 		for(int i = 0; i < numberOfSongs; i++){
-			add_song_to_list(NULL, i, gems_profile_manager_get_userid(NULL));	
+			add_song_to_list("", i, gems_profile_manager_get_userid(NULL));	
 			//TODO: third parameter must be user id of the composer, now we are using default
 		}
 
@@ -106,8 +106,11 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 	
 			
 	//TODO: add correct font for the text		
+	gchar * filename = "Name of the song"; // TESTING
+
+	songName = tangle_button_new_with_background_actor(clutter_text_new_with_text(TEXT_NORMAL, "Name of the song"));
+	clutter_actor_set_name(songName, filename);
 
-	songName = tangle_button_new_with_background_actor(clutter_text_new_with_text("Times", "Name of the song"));
 
 	if(listImage == NULL)
 		return FALSE;	
@@ -132,7 +135,7 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 	
 	clutter_container_add_actor(listContainer, songName);
 
-	labelParams->path = g_strdup_printf("%s/label_%d.csv", configure_get_jammo_directory(), user_id);
+	labelParams->path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), user_id, loopName);
 	
 	command = g_strdup_printf("ls %s 1> /dev/null 2> /dev/null", labelParams->path);
 	
@@ -155,7 +158,7 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 				clutter_actor_get_parent(reviewButton));
 
 	g_signal_connect_swapped(songName, "button-press-event", G_CALLBACK(song_name_press_action), songName);
-	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_press_action), songName);		
+	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_release_action), songName);
 	
 	if(label != 0){	
 		strcpy(labelParams->parentview, "jammosongs");
