@@ -3,6 +3,7 @@
 #include <tangle.h>
 #include <string.h>
 #include "community_utilities.h"
+#include "mysongs.h"
 
 static ClutterContainer *imageList = 0;
 static ClutterContainer *widgets = 0;
@@ -11,16 +12,15 @@ ClutterActor *recordName = 0;
 ClutterActor *composerName = 0;
 TextField recordNameTextField;
 TextField composerNameTextField;
-gchar *filepath;
+const gchar* path;
 
-
-void start_record_cover_tool(){
-
-	filepath = g_strdup_printf("%s/label_%d.csv", configure_get_jammo_directory(), gems_profile_manager_get_userid(NULL));
+void start_record_cover_tool(const gchar* filepath){
 		
 	FILE* file;
 	char coverInfo[200];
 
+	path = filepath;
+
 	char *path = "/opt/jammo/communitymenu/INSTRUMENTS/";
 
 	printf("Starting record cover tool\n");
@@ -96,8 +96,6 @@ void end_record_cover_tool(){
 	clutter_text_set_text(CLUTTER_TEXT(recordNameTextField.text), "");
 	clutter_text_set_text(CLUTTER_TEXT(composerNameTextField.text), "");
 
-	g_free(filepath);
-
 	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("record-cover-view")));
 	clutter_actor_show(jammo_get_actor_by_id("mysongs-view"));
 
@@ -125,7 +123,7 @@ void record_cover_ok_pressed(){
 	FILE* file;
 	gchar *data;
 	
-	if((file = fopen(filepath, "w")) != NULL){
+	if((file = fopen(path, "w")) != NULL){
 		
 		data =  g_strdup_printf("%s,%s,%s,",
 			strlen(clutter_text_get_text(CLUTTER_TEXT(recordName))) == 0 ? "0" : clutter_text_get_text(CLUTTER_TEXT(recordName)),
@@ -138,6 +136,8 @@ void record_cover_ok_pressed(){
 		fclose(file);
 	}
 
+	mysongs_update_label_button(path);
+
 	end_record_cover_tool();
 
 }
