@@ -3,7 +3,7 @@
 
 #include <tangle.h>
 
-void start_record_cover_tool();
+void start_record_cover_tool(const gchar* filepath);
 void record_cover_ok_pressed();
 void record_cover_cancel_pressed();
 void end_record_cover_tool();
