@@ -384,7 +384,7 @@ static void levelview_loaded(ClutterActor *levelview, gpointer none) {
 }
 
 void sequencer_start_with_file(gchar* filename) {
-	start_gamesmenu(); //When level starts, it suppose that gamesmenu is also visible
+	gamesmenu_show(); //When level starts, it suppose that gamesmenu is also visible
 	gamesmenu_start_first_task_on_this_level("empty-level");
 
 	gchar *message = g_strdup_printf("Starting sequencer from file '%s'",filename);
@@ -487,6 +487,8 @@ static void leave_fullsequencer() {
 }
 
 void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
+	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "");
+	jammo_mentor_shut_up(jammo_mentor_get_default());
 	leave_fullsequencer();
 	startmenu_goto_startmenu(NULL,NULL);
 }
@@ -582,9 +584,7 @@ void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none)
 	g_free(outputFilename);
 }
 
-
-void sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer none){
-	cem_add_to_log("Saving project file",J_LOG_INFO);
+void sequencer_save_project(){
 	gchar* meta_data = g_strdup_printf
       ("\"pitch\" : \"%s\",\n\"tempo\" : %d,\n\"duration\" : %" G_GUINT64_FORMAT ",\n",
       jammo_sequencer_get_pitch(static_sequencer),
@@ -594,6 +594,11 @@ void sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer
 	save_composition(configure_get_projects_directory(), "", jammo_get_actor_by_id("fullsequencer-container-for-tracks"),meta_data);
 	g_free(meta_data);
 	cem_add_to_log("  Saving ready",J_LOG_INFO);
+}
+
+void sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer none){
+	cem_add_to_log("Saving project file",J_LOG_INFO);
+	sequencer_save_project();
 	return;
 }
 
