@@ -265,10 +265,7 @@ void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *sour
 	rotate_to_place(effect_sample_looper, combo.e);
 }
 
-
-//This is just random.
-void fullsequencer_loop_crazy_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	cem_add_to_log("fullsequencer_loop_crazy_clicked-clicked",J_LOG_USER_ACTION);
+void sequencer_loop_randomize_wheels(){
 	GRand *random_gen = g_rand_new();
 
 	gint rot_rhyt = g_rand_int_range(random_gen, -30, 30);
@@ -284,6 +281,12 @@ void fullsequencer_loop_crazy_clicked (TangleAction *action, GObject *source, co
 	g_rand_free(random_gen);
 }
 
+//This is just random.
+void fullsequencer_loop_crazy_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	cem_add_to_log("fullsequencer_loop_crazy_clicked-clicked",J_LOG_USER_ACTION);
+	sequencer_loop_randomize_wheels();
+}
+
 
 //////////////////////////////////////
 
