@@ -33,6 +33,7 @@ Call this: sequencer_track_view_tune_width
 #include "jammer_view.h"
 #include "startmenu.h"
 
+#include "backingtrack_selection.h"
 #include "../../cem/cem.h"
 static int width_of_slot = 40;
 
@@ -118,6 +119,7 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 			cem_add_to_log(" Backing_track pressed",J_LOG_USER_ACTION);
 			clutter_actor_show(jammo_get_actor_by_id("backingtrack-selection-view"));
 			clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
+			backingtrack_selection_set_track_view(CLUTTER_ACTOR(track_view));
 			}
 		}
 
@@ -195,9 +197,16 @@ Also when user moves volume-slider, this is called.
 static void set_track_volume_and_button_texture(JammoPlayingTrack* jammotrack, TangleButton* volume_button, gfloat new_volume) {
 	//printf("changing volume to %f\n",new_volume);
 
+	//new_volume is float and can be -0 (negative zero). -0 = +0. But it looks weird on logs.
+	if (new_volume==0)
+		new_volume=0.0;
+
 	jammo_playing_track_set_volume(jammotrack,new_volume);
 
-	gchar* message = g_strdup_printf("Volume changed to %f",new_volume);
+	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(volume_button));
+	const gchar* name_of_track = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
+
+	gchar* message = g_strdup_printf("Volume changed to %f for track '%s' ",new_volume,name_of_track);
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
 
@@ -305,7 +314,10 @@ gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer d
 		//-50 is height of the visible marker.
 		gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50)*current_volume;
 		//printf("new place: %f\n",new_place);
-		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 50, "offset-y", new_place, NULL);
+		//Disconnect notify::offset-y for a while: we are making to change offset-y
+		g_signal_handlers_disconnect_by_func(scroll_action, sequencer_volumebar_used,NULL);
+		g_object_set(scroll_action, "offset-y", new_place, NULL);
+		g_signal_connect(scroll_action, "notify::offset-y", G_CALLBACK(sequencer_volumebar_used), NULL);
 		g_object_set_data(G_OBJECT(volume_scroller),"track",jammotrack);
 		if (last_pressed_volume_button)
 			tangle_button_set_selected(last_pressed_volume_button,FALSE);
@@ -354,9 +366,13 @@ Functions for json
 
 
 void fullsequencer_play_clicked (TangleButton* tanglebutton, gpointer none){
-	gchar* message = g_strdup_printf("fullsequencer: Play-Stop-Button pressed clicked");
+	gchar* message;
+	if (tangle_button_get_selected(tanglebutton))
+		message = "fullsequencer: Play-Button pressed";
+	else
+		message = "fullsequencer: Stop-Button pressed";
+
 	cem_add_to_log(message,J_LOG_USER_ACTION);
-	g_free(message);
 
 	//Button is (tangle-)binded to sequencer, so there are nothing to do.
 }
@@ -387,12 +403,11 @@ void fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none)
 Also prepare cursor.
 */
 
-void sequencer_track_view_tune_width() {
-	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
-	guint64 duration;
-	duration = jammo_sequencer_get_duration(sequencer);
+void sequencer_track_view_set_duration(guint64 duration) {
+	printf("sequencer_track_view_tune_width\n");
 
-	//g_print("Duration: %" G_GUINT64_FORMAT "\n", duration);
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	g_print("tune...Duration: %" G_GUINT64_FORMAT "\n", duration);
 
 	gint tempo_factory = 4;
 	//We want operate whole time with guint64.
@@ -483,18 +498,17 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 	clutter_container_add_actor(CLUTTER_CONTAINER(container),panel_widget);
 	clutter_actor_set_height(container,clutter_actor_get_height(container)+track_height);
 
-	//Set saved volume
-	ClutterActor* volume_scroller = jammo_get_actor_by_id("fullsequencer-volumebar-scroller");
-	ClutterAction* scroll_action;
-	scroll_action = tangle_actor_get_action_by_type(volume_scroller, TANGLE_TYPE_SCROLL_ACTION);
-
 	JammoPlayingTrack* jammotrack;
 	g_object_get(track_view_actor,"track",&jammotrack,NULL);
-
-	set_track_volume_and_button_texture(jammotrack, TANGLE_BUTTON(volume_button),volume);
-
-	//Set saved mute-state
-	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), muted);
+	if (jammotrack) {
+		//volume
+		set_track_volume_and_button_texture(jammotrack, TANGLE_BUTTON(volume_button),volume);
+		//mute-state
+		jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(jammotrack), muted);
+	}
+	else {
+		cem_add_to_log("No audio-track inside saved track-view",J_LOG_FATAL);
+	}
 }
 
 
@@ -504,7 +518,13 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
 	//printf("Making editing track (duration: %" G_GUINT64_FORMAT ")\n", duration_of_tracks);
 
-	guint64 duration_of_one_slot = duration_of_tracks / number_of_slots;
+	guint64 duration_of_one_slot;
+
+	if(number_of_slots == 0)
+		duration_of_one_slot = 0;
+	else	
+		duration_of_one_slot = duration_of_tracks / number_of_slots;
+		
 	ClutterActor *label;
 	gchar* name_of_label_button="";
 	JammoTrack* track;
@@ -574,6 +594,56 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 	return track_view_actor;
 }
 
+
+ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, gchar* audio, gchar* image, gchar* name_of_track_view) {
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
+
+	guint64 duration_of_one_slot;
+
+	if (number_of_slots == 0)
+		duration_of_one_slot = 0;
+	else
+		duration_of_one_slot = duration_of_tracks / number_of_slots;
+
+
+	ClutterActor *label;
+	gchar* name_of_label_button="";
+	JammoTrack* track;
+	ClutterActor* track_view_actor;
+
+	//MEAM-track
+	track = JAMMO_TRACK(jammo_backing_track_new(audio));
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
+
+	//CHUM-track-view
+	ClutterActor* back_actor = clutter_texture_new_from_file(image,NULL);
+	g_object_set(back_actor,"repeat-x",true,"height",50.0,NULL);
+
+	track_view_actor = jammo_track_view_new(track);
+	tangle_widget_set_background_actor(TANGLE_WIDGET(track_view_actor),back_actor);
+
+	g_object_set(track_view_actor, "name", name_of_track_view, NULL);
+
+	//Add track-view to container
+	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+	clutter_container_add_actor(CLUTTER_CONTAINER(container),track_view_actor);
+	clutter_actor_set_height(container,clutter_actor_get_height(container)+(float)track_height);
+
+	name_of_label_button = "/opt/jammo/sequencer/label_backingtrack.png";
+
+	label = tangle_button_new_with_background_actors (
+       clutter_texture_new_from_file(name_of_label_button, NULL), /* normal */
+       clutter_texture_new_from_file(name_of_label_button, NULL));  /* interactive TODO*/
+	g_signal_connect(label, "clicked", G_CALLBACK(pressed_sequencer_button_track_label), track_view_actor);
+
+
+	create_control_panel_entry(track_view_actor, label, name_of_track_view, muted, volume);
+
+	return track_view_actor;
+}
+
+
 ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, gchar* name_of_track_view) {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
