@@ -12,6 +12,7 @@
 #include "help.h"
 #include "jammosounds.h"
 #include "discuss.h"
+#include "mysongs.h"
 #include "profile_viewer.h"
 
 static ClutterContainer *messageList = 0;
@@ -22,41 +23,27 @@ static gchar *id;
 static TextField text;
 gchar filepath [150];
 
-void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int index){
+void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int index)
+{
+	GList *l = 0; //Iterator
 
-	selected_index = index;
-
-	int i = 0;
-	id = id_;
-
-
-	messages = listOfMessages; 
-
-	ClutterActor* thread_view = NULL;
+	selected_index 	= index;
+	messages 	= listOfMessages;
+	id 		= id_;
 
 	puts("starting thread...");
 
-	if(strcmp(id, "jammosongs") == 0 )
-	thread_view = jammo_get_actor_by_id("single-thread-view");	//if you want to use different layout for the threads view, modify this. Although it crashes for somereason is you change this
-
-	if(strcmp(id, "discuss") == 0)
-	thread_view = jammo_get_actor_by_id("single-thread-view");
-
-	if(strcmp(id, "helpdesk") == 0)
-	thread_view = jammo_get_actor_by_id("single-thread-view");
-
-	if(thread_view){
-
-
-
+	ClutterActor* thread_view = jammo_get_actor_by_id("single-thread-view");
 
+	if(thread_view)
+	{
 		clutter_actor_show(thread_view);
 
 		if(strcmp(id, "jammosongs") == 0){
 			clutter_actor_hide(jammo_get_actor_by_id("text-answer-widgets"));
 			clutter_actor_show(jammo_get_actor_by_id("select-comment-type"));
 
-		}else if(strcmp(id, "discuss") == 0){
+		}else if((strcmp(id, "discuss") == 0) || (strcmp(id, "mysongs") == 0)){
 			text.text = jammo_get_actor_by_id("answer-field");
 			text.lineCount = 8;
 			text.max_characters = 500;
@@ -70,35 +57,24 @@ void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int ind
 			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
 			clutter_text_set_text(CLUTTER_TEXT(text.text), "");
 		}	
-	
 		
 		if(messages != NULL)
 		{
-		
 			messages = g_list_first(messages);
 			
 			messageList = CLUTTER_CONTAINER(jammo_get_actor_by_id("single-thread-list-scrollable"));		
-			
 				
-			do{	
-				if(i > 0)
-				messages = messages->next;
-
-				add_message_to_list(messages->data, index);
-				i++;
-				
-			} while(messages->next != NULL);
+			for(l = messages; l; l = l->next)
+			add_message_to_list(l->data, index);
 		}
 	}
 	else
 	puts("can't find single-thread-view");
-	
-
 }
 
 
-void text_comment_view(){
-
+void text_comment_view()
+{
 	clutter_actor_hide(jammo_get_actor_by_id("select-comment-type"));
 	clutter_actor_show(jammo_get_actor_by_id("text-answer-widgets"));
 	text.text = jammo_get_actor_by_id("answer-field");
@@ -106,14 +82,13 @@ void text_comment_view(){
 	text.max_characters = 500;
 	text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
 	clutter_text_set_text(CLUTTER_TEXT(text.text), "");
-
 }
 
 
 void add_message_to_list(gpointer data, int i) 
 {
 	message *msg = data;
-printf("%d   %d \n", i, msg->index);
+
 	if(msg->index == i)	//If the messages index is the same as i (question number, we selected) then add it to list.
 	{
 		int index = 0;
@@ -142,24 +117,22 @@ printf("%d   %d \n", i, msg->index);
 		ClutterColor text_color = { 0, 0, 0, 255 };
 		ClutterColor line_color = { 144, 148, 140, 255 };
 
-
 		ClutterActor* avatarBackground = clutter_group_new();
 		
-		clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
+		clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), clutter_texture_new_from_file(
+						"/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
 		ClutterActor* writer = tangle_button_new_with_background_actor(avatarBackground);
 		
-		ClutterActor* name = clutter_text_new_full("Comic Sans MS 14", msg->sender, &text_color);
-		ClutterActor* date = clutter_text_new_full("Comic Sans MS 14", msg->time, &text_color);
-		//ClutterActor* avatar_ = clutter_text_new_full("Comic Sans MS 12", msg->avatar, &text_color);
+		ClutterActor* name = clutter_text_new_full(TEXT_NORMAL, msg->sender, &text_color);
+		ClutterActor* date = clutter_text_new_full(TEXT_NORMAL, msg->time, &text_color);
+		//ClutterActor* avatar_ = clutter_text_new_full(TEXT_SMALL, msg->avatar, &text_color);
 		community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarBackground));
 		clutter_container_add_actor(CLUTTER_CONTAINER(listContainer), writer);
 		
-
-	
 		index = (index+1) % 3;
 
 		if(strcmp(msg->title, "") != 0){
-			ClutterActor* title = clutter_text_new_full("Comic Sans MS 16", msg->title, &text_color);
+			ClutterActor* title = clutter_text_new_full(TEXT_LARGE, msg->title, &text_color);
 			clutter_actor_set_position(title, 80, 10);
 			clutter_container_add_actor(listContainer, title);
 
@@ -178,10 +151,9 @@ printf("%d   %d \n", i, msg->index);
 		clutter_container_add_actor(listContainer, date);
 		
 		g_signal_connect_swapped(writer, "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
-		
 
 		if(msg->type == TEXT_COMMENT){
-			ClutterActor* message = clutter_text_new_full("Comic Sans MS 12", msg->msg, &text_color);
+			ClutterActor* message = clutter_text_new_full(TEXT_SMALL, msg->msg, &text_color);
 			clutter_text_set_line_wrap_mode(CLUTTER_TEXT(message), PANGO_WRAP_WORD_CHAR);
 				//clutter_actor_set_size(message,(88*7)+40, ((MAX/88)*27));
 			clutter_actor_set_width(message, (88*7)+40);
@@ -189,7 +161,6 @@ printf("%d   %d \n", i, msg->index);
 			clutter_actor_set_position(message, 80, 80); 
 			clutter_container_add_actor(listContainer, message);
 			h = (clutter_actor_get_height(avatarBackground) + pango_layout_get_line_count(clutter_text_get_layout(CLUTTER_TEXT(message)))*25);	
-		
 		}
 
 		if(msg->type == VOICE_COMMENT){
@@ -207,9 +178,6 @@ printf("%d   %d \n", i, msg->index);
 
 		}
 
-
-	
-
 		messageBackground = clutter_rectangle_new_with_color(&line_color);
 		clutter_actor_set_size(messageBackground, 800, 2);
 
@@ -223,23 +191,26 @@ printf("%d   %d \n", i, msg->index);
 	}
 }
 
-void add_comment(){
-
+void add_comment()
+{
 	message *msg;
-	message *temp = g_list_first(messages)->data;
 	time_type now;
 	now = get_current_time();
 
-	//clutter_actor_destroy(messageList);
+	if(clutter_text_get_text(CLUTTER_TEXT(text.text)) == NULL || (strcmp(clutter_text_get_text(CLUTTER_TEXT(text.text)), "") == FALSE))
+	{
+		printf("No text entered\n");
+		return;
+	}
+
 	clear_container(messageList);
-	
 
 	msg = malloc(sizeof(message));
 	msg->index = selected_index;	//asd
 	msg->msg = malloc((strlen(clutter_text_get_text(CLUTTER_TEXT(text.text)))+1) * sizeof(gchar));
 	msg->user_id = 0;
 	strcpy(msg->msg, clutter_text_get_text(CLUTTER_TEXT(text.text)));
-	strcpy(msg->title, temp->title);
+	strcpy(msg->title, messages == 0 ? "" : ((message*)g_list_first(messages)->data)->title);
 	strcpy(msg->sender, "Sender");
 	strcpy(msg->time, now.time); 
 	msg->filepath = 0;
@@ -248,11 +219,10 @@ void add_comment(){
 	messages = g_list_append(messages, (gpointer)msg);
 
 	start_thread_view(messages, id, NULL, selected_index);
-
 }
 
-void add_voice_comment(){
-
+void add_voice_comment()
+{
 	static gboolean isrecording = FALSE;
 	message *msg;
 	time_type now;
@@ -284,14 +254,10 @@ void add_voice_comment(){
 
 		start_thread_view(messages, id, NULL, selected_index);		
 	}
-
-	
-
 }
 
-void end_single_thread(){
-
-
+void end_single_thread()
+{
 	community_clear_paramslist(paramsList);
 	paramsList = 0;
 
@@ -312,6 +278,9 @@ void end_single_thread(){
 
 	else if (strcmp(id, "discuss") == 0)
 	start_discussionthreads();
+	
+	else if(strcmp(id, "mysongs") == 0)
+	start_mysongs();
 
 	else {} //do nothing
 }
