@@ -31,6 +31,7 @@ enum {
 enum {
 	LISTENED,
 	DRAG_BEGIN,
+	DRAG_END,
 	DROPPED,
 	LAST_SIGNAL
 };
@@ -42,6 +43,8 @@ struct _JammoSampleButtonPrivate {
 	gint loop_id;
 	JammoSequencer* sequencer;
 	ClutterAction* drag_action;
+	
+	guint dragging : 1;
 };
 
 static const GEnumValue sample_type_values[] = {
@@ -480,6 +483,14 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 					 g_cclosure_marshal_VOID__VOID,
 					 G_TYPE_NONE, 0);
 
+	//Drag-ends happens every time dragging is ended (e.g. sample-button is dropped to stage)
+	signals[DRAG_END] = g_signal_new("drag-end", G_TYPE_FROM_CLASS(gobject_class),
+	                                 G_SIGNAL_RUN_LAST, 0,
+					 NULL, NULL,
+					 g_cclosure_marshal_VOID__VOID,
+					 G_TYPE_NONE, 0);
+
+	//dropped happens only when jammo-sample-button is dropped on jammo-editing-track-view (also drag-ends happens then)
 	signals[DROPPED] = g_signal_new("dropped", G_TYPE_FROM_CLASS(gobject_class),
 	                                 G_SIGNAL_RUN_LAST, 0,
 					 NULL, NULL,
@@ -494,8 +505,16 @@ static void jammo_sample_button_init(JammoSampleButton* sample_button) {
 }
 
 static void on_drag_begin(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data) {
-	jammo_sample_get_duration(JAMMO_SAMPLE_BUTTON(user_data)->priv->sample);
-	g_signal_emit(JAMMO_SAMPLE_BUTTON(user_data), signals[DRAG_BEGIN], 0);
+	JammoSampleButton* sample_button;
+	
+	sample_button = JAMMO_SAMPLE_BUTTON(user_data);
+
+	sample_button->priv->dragging = TRUE;
+
+	jammo_sample_stop_all();
+
+	jammo_sample_get_duration(sample_button->priv->sample);
+	g_signal_emit(sample_button, signals[DRAG_BEGIN], 0);
 }
 
 static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat event_x, gfloat event_y, ClutterModifierType modifiers, gpointer user_data) {
@@ -505,6 +524,7 @@ static void on_drag_end(ClutterDragAction* action, ClutterActor* actor, gfloat e
 	if (JAMMO_IS_EDITING_TRACK_VIEW(parent)) {
 		clutter_container_remove_actor(CLUTTER_CONTAINER(parent), CLUTTER_ACTOR(actor));
 	}
+	g_signal_emit(JAMMO_SAMPLE_BUTTON(user_data), signals[DRAG_END], 0);
 }
 
 static void on_stopped(JammoSample* sample, gpointer user_data) {
@@ -522,11 +542,15 @@ static gboolean on_clicked(TangleButton* button, gpointer user_data) {
 	
 	sample_button = JAMMO_SAMPLE_BUTTON(button);
 
-	jammo_sample_stop_all();
-	jammo_sample_play(sample_button->priv->sample);
-	
-	g_signal_connect(sample_button->priv->sample, "stopped", G_CALLBACK(on_stopped), sample_button);
+	if (!sample_button->priv->dragging) {
+		jammo_sample_stop_all();
+		jammo_sample_play(sample_button->priv->sample);
+
+		g_signal_connect(sample_button->priv->sample, "stopped", G_CALLBACK(on_stopped), sample_button);
+	}
 	
+	sample_button->priv->dragging = FALSE;
+
 	return FALSE;
 }
 
