@@ -563,3 +563,49 @@ return FALSE;
 }
 
 
+
+
+static void clutter_actor_flashD(ClutterTimeline* t, gpointer data){
+	ClutterAnimation* animation;
+	ClutterTimeline* timeline;
+	ClutterActor* actor = CLUTTER_ACTOR(data);
+	float width = clutter_actor_get_width(actor);
+	float height = clutter_actor_get_height(actor);
+	animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 250, "width", width*0.90909, "height",height*0.90909, NULL);
+	timeline = clutter_animation_get_timeline(animation);
+}
+
+static void clutter_actor_flashC(ClutterTimeline* t, gpointer data){
+	g_signal_handlers_disconnect_by_func(t, clutter_actor_flashC, data);
+	ClutterAnimation* animation;
+	ClutterTimeline* timeline;
+	ClutterActor* actor = CLUTTER_ACTOR(data);
+	float width = clutter_actor_get_width(actor);
+	float height = clutter_actor_get_height(actor);
+	animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 250, "width", width*1.1, "height",height*1.1, NULL);
+	timeline = clutter_animation_get_timeline(animation);
+	g_signal_connect(timeline, "completed", G_CALLBACK(clutter_actor_flashD), actor);
+}
+
+static void clutter_actor_flashB(ClutterTimeline* t, gpointer data){
+	g_signal_handlers_disconnect_by_func(t, clutter_actor_flashB, data);
+	ClutterAnimation* animation;
+	ClutterTimeline* timeline;
+	ClutterActor* actor = CLUTTER_ACTOR(data);
+	float width = clutter_actor_get_width(actor);
+	float height = clutter_actor_get_height(actor);
+	animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 250, "width", width*0.90909, "height",height*0.90909, NULL);
+	timeline = clutter_animation_get_timeline(animation);
+	g_signal_connect(timeline, "completed", G_CALLBACK(clutter_actor_flashC), actor);
+}
+
+void jammo_clutter_actor_flash(ClutterActor* actor) {
+	ClutterAnimation* animation;
+	ClutterTimeline* timeline;
+	float width = clutter_actor_get_width(actor);
+	float height = clutter_actor_get_height(actor);
+	animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 250, "width", width*1.1, "height",height*1.1, NULL);
+	timeline = clutter_animation_get_timeline(animation);
+	g_signal_connect(timeline, "completed", G_CALLBACK(clutter_actor_flashB), actor);
+}
+
