@@ -18,6 +18,7 @@
 
 #include "../jammo.h"
 #include "../../cem/cem.h"
+#include "../../gems/gems.h"
 
 #define NUM_OF_CELLS 45
 #define NUM_OF_SPOTS 9
@@ -30,6 +31,8 @@ ClutterActor *mySpot[NUM_OF_SPOTS];
 ClutterActor *ls_point_container;
 ClutterActor *display_error_actor; // DIsplay an image in case passowrd error
 
+ClutterActor* loginname_text = NULL;
+
 /**
  *
  */
@@ -185,6 +188,7 @@ void login_screen() {
 	// Get the stage created
 	ClutterActor *stage = jammo_get_actor_by_id("pen-gesture-view");
 	clutter_actor_set_reactive(stage, TRUE);
+	clutter_actor_set_size (stage, 800, 480);
 
 	// Add Background to the stage
 	gchar* pg_directory_path = PG_IMAGES_DIR;
@@ -237,6 +241,27 @@ void login_screen() {
 	create_all_knots(ls_point_container, mySpot, on_spot_enter, verify_path);
 
 	pg_set_select_option_screen(stage);
+	
+	gchar* loginname = gems_get_login_username();
+	if(!loginname) loginname = g_strdup("defaultuser");
+	
+	ClutterColor uname_color = { 0xff, 0xff, 0xff, 0x99 };
+	loginname_text = clutter_text_new_full("Sans 18",loginname,&uname_color);
+	clutter_actor_set_size(loginname_text,50,50);
+	clutter_actor_set_position(loginname_text,10,10);
+	clutter_container_add_actor(CLUTTER_CONTAINER(stage),loginname_text);
+	clutter_actor_hide(loginname_text);
+	
+	g_free(loginname);
 
 	clutter_actor_show(stage);
 }
+
+void login_screen_set_login_name(gchar* loginname)
+{
+	if(loginname && loginname_text)
+	{
+		clutter_text_set_text((ClutterText*)loginname_text,loginname);
+		clutter_actor_show(loginname_text);
+	}
+}
