@@ -530,7 +530,7 @@ gint StorageAgent::readProfile(gchar* username)
 				g_error_free(error);
 				if(profilefile) g_free(profilefile);
 				if(filename) g_free(filename);
-				return 1;
+				return PROFILE_READ_FAILURE;
 			}
 		}
 		else
@@ -544,6 +544,8 @@ gint StorageAgent::readProfile(gchar* username)
 			
 			// Extract version
 			version = *(guint8*)&contents[0];
+			
+			// TODO check if the profile can be converted to current version !
 			if(version != JAMMO_PROFILE_VERSION)
 			{
 				logmsg = g_strdup_printf("StorageAgent::readProfile : Profile version is not compatible, read version = %d, JAMMO_PROFILE_VERSION = %d. Profile is not loaded!",
@@ -554,7 +556,7 @@ gint StorageAgent::readProfile(gchar* username)
 				if(profilefile) g_free(profilefile);
 				if(filename) g_free(filename);
 				if(contents) g_free(contents);
-				return 3;
+				return PROFILE_VERSION_MISMATCH;
 			}
 			else
 			{
@@ -608,14 +610,14 @@ gint StorageAgent::readProfile(gchar* username)
 		g_free(logmsg);
 		if(filename) g_free(filename);
 		if(profilefile) g_free(profilefile);
-		return 2;
+		return PROFILE_NOT_FOUND;
 	}
   
 	if(contents) g_free(contents);
 	if(filename) g_free(filename);
 	if(profilefile) g_free(profilefile);
 
-	return 0;
+	return PROFILE_LOADED;
 }
 
 // Write encrypted profile - raw
