@@ -17,6 +17,7 @@
 #include "messagehandler.h"
 #include "gems_message_functions.h"
 #include "groupmanager.h"
+#include "gems_utils.h"
 #include <glib.h>
 #include <arpa/inet.h>
 #include <string.h>
@@ -434,6 +435,8 @@ void jammo_gems_cleanup_lists()
 {
 	gems_components* components = gems_get_data();
 	
+	gems_free_list_saved_profiles();
+	
 	if(components->initialized_connections != NULL)
 	{
 		// Initialized connections
