@@ -75,12 +75,24 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 	}
 	
 	// Try to load profile
-	if(!profilemanager_storage_load_profile(pm, username))
+	switch(profilemanager_storage_load_profile(pm, username))
 	{
-		cem_add_to_log("Authentication failure, profile not found.", J_LOG_ERROR);
-		return LOGIN_NO_PROFILE;
+		case PROFILE_LOADED:
+			cem_add_to_log("Profile loaded.", J_LOG_DEBUG);
+			break;
+		case PROFILE_READ_FAILURE:
+			cem_add_to_log("Authentication failure, profile cannot be read.", J_LOG_ERROR);
+			return LOGIN_PROFILE_READ_ERROR;
+		case PROFILE_NOT_FOUND:
+			cem_add_to_log("Authentication failure, profile not found.", J_LOG_ERROR);
+			return LOGIN_NO_PROFILE;
+		case PROFILE_VERSION_MISMATCH:
+			cem_add_to_log("Authentication failure, profile version is not compatible.", J_LOG_ERROR);
+			return LOGIN_INVALID_PROFILE;
+		default:
+			cem_add_to_log("Authentication - unknown state when loading profile ?",J_LOG_ERROR);
+			break;
 	}
-	else cem_add_to_log("Profile loaded", J_LOG_DEBUG);
 	
 	// Create password from data
 	if((passwd = gems_security_create_password(passworddata,profilemanager_storage_get_password_salt(pm))) == NULL)
@@ -177,71 +189,82 @@ gint gems_profile_manager_set_user(gchar* username)
 		}
 		
 		// Profile does not exist
-		if(!profilemanager_storage_load_profile(gems_get_profile_manager(),gems_get_login_username()))
+		switch(profilemanager_storage_load_profile(gems_get_profile_manager(),gems_get_login_username()))
 		{
-			if(gems_get_data()->teacher_profile_request_timer)
+			case PROFILE_NOT_FOUND:
 			{
-				// Not enough time spent
-				if(g_timer_elapsed(gems_get_data()->teacher_profile_request_timer,NULL) < TEACHER_PROFILE_REQUEST_LIMIT) return TRUE;
-			}
-			// create new timer
-			else gems_get_data()->teacher_profile_request_timer = g_timer_new(); // when first run this should be reached
-			
-			// New requests can be made & connection to teacher exists and request was sent
-			if((gems_get_teacher_profile_request_count() < TEACHER_PROFILE_REQUEST_MAX_COUNT) && 
-				(gems_communication_do_profile_request_to_teacher(gems_get_login_username())))
-			{
-				// set waiting for teacher - no logins should be possible!
-				gems_set_waiting_profile_from_teacher();
-				gems_increase_teacher_profile_request_counter();
-				
-				// restart timer
-				g_timer_start(gems_get_data()->teacher_profile_request_timer);
-				
-				// Add timed function if not set
-				if(gems_get_data()->profile_request_timeout_sid == 0)
+				if(gems_get_data()->teacher_profile_request_timer)
 				{
-					gems_get_data()->profile_request_timeout_sid = 
-						g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_profile_manager_set_user, NULL, gems_unset_teacher_profile_timeout_sid);
+					// Not enough time spent
+					if(g_timer_elapsed(gems_get_data()->teacher_profile_request_timer,NULL) < TEACHER_PROFILE_REQUEST_LIMIT) return TRUE;
 				}
-				return CHANGE_USER_WAITING_PROFILE; // Equals TRUE, the timed function remains
-			}
+				// create new timer
+				else gems_get_data()->teacher_profile_request_timer = g_timer_new(); // when first run this should be reached
 			
-			// no teacher or cannot send request or limit reached -> no profile for user
-			else
+				// New requests can be made & connection to teacher exists and request was sent
+				if((gems_get_teacher_profile_request_count() < TEACHER_PROFILE_REQUEST_MAX_COUNT) && 
+					(gems_communication_do_profile_request_to_teacher(gems_get_login_username())))
+				{
+					// set waiting for teacher - no logins should be possible!
+					gems_set_waiting_profile_from_teacher();
+					gems_increase_teacher_profile_request_counter();
+				
+					// restart timer
+					g_timer_start(gems_get_data()->teacher_profile_request_timer);
+				
+					// Add timed function if not set
+					if(gems_get_data()->profile_request_timeout_sid == 0)
+					{
+						gems_get_data()->profile_request_timeout_sid = 
+							g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_profile_manager_set_user, NULL, gems_unset_teacher_profile_timeout_sid);
+					}
+					return CHANGE_USER_WAITING_PROFILE; // Equals TRUE, the timed function remains
+				}
+			
+				// no teacher or cannot send request or limit reached -> no profile for user
+				else
+				{
+					// Destroy timer and set to NULL
+					if(gems_get_data()->teacher_profile_request_timer)
+					{
+						g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
+						gems_get_data()->teacher_profile_request_timer = NULL;
+					}
+				
+					// Make sure that source is removed
+					if(gems_get_data()->profile_request_timeout_sid != 0) g_source_remove(gems_get_data()->profile_request_timeout_sid);
+					gems_reset_teacher_profile_request_counter();
+				
+					// No profile for this username, clear it
+					gems_clear_login_username();
+				
+					return CHANGE_USER_NO_PROFILE;
+				}
+			}
+			// profile exists and is loaded
+			case PROFILE_LOADED:
 			{
+				// Allow to continue
+				gems_unset_waiting_profile_from_teacher();
+			
 				// Destroy timer and set to NULL
 				if(gems_get_data()->teacher_profile_request_timer)
 				{
 					g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
 					gems_get_data()->teacher_profile_request_timer = NULL;
 				}
-				
-				// Make sure that source is removed
-				if(gems_get_data()->profile_request_timeout_sid != 0) g_source_remove(gems_get_data()->profile_request_timeout_sid);
-				gems_reset_teacher_profile_request_counter();
-				
-				// No profile for this username, clear it
-				gems_clear_login_username();
-				
+			
+				// Equals to FALSE (0) so the timeout function should be removed
+				return CHANGE_USER_OK;
+			}
+			// TODO handle this - should not be possible
+			case PROFILE_READ_FAILURE:
 				return CHANGE_USER_NO_PROFILE;
-			}
-		}
-		// profile exists and is loaded
-		else
-		{
-			// Allow to continue
-			gems_unset_waiting_profile_from_teacher();
-			
-			// Destroy timer and set to NULL
-			if(gems_get_data()->teacher_profile_request_timer)
-			{
-				g_timer_destroy(gems_get_data()->teacher_profile_request_timer);
-				gems_get_data()->teacher_profile_request_timer = NULL;
-			}
-			
-			// Equals to FALSE (0) so the timeout function should be removed
-			return CHANGE_USER_OK;
+			// TODO handle this - should not be possible
+			case PROFILE_VERSION_MISMATCH:
+				return CHANGE_USER_NO_PROFILE;
+			default:
+				return FALSE;
 		}
 	}
 }
