@@ -216,8 +216,29 @@ gboolean gems_service_profile_process_profile_upload(gems_connection* element)
 							if(g_strcmp0(username,gems_profile_manager_get_loaded_username()) == 0)
 							{
 								cem_add_to_log("Got profile from teacher for user whose profile is already loaded, clearing loaded.",J_LOG_DEBUG);
-								if(profilemanager_storage_reload_profile(gems_get_profile_manager())) cem_add_to_log("Profile reloaded",J_LOG_DEBUG);
-								else cem_add_to_log("Cannot reload profile",J_LOG_DEBUG);
+								switch(profilemanager_storage_reload_profile(gems_get_profile_manager()))
+								{
+									case PROFILE_LOADED:
+										cem_add_to_log("Profile reloaded.",J_LOG_DEBUG);
+										break;
+									case PROFILE_READ_FAILURE:
+										cem_add_to_log("Profile reload failure, cannot read profile.",J_LOG_DEBUG);
+										break;
+									case PROFILE_NOT_FOUND:
+										cem_add_to_log("Cannot reload profile, profile not found ?",J_LOG_DEBUG);
+										break;
+									case PROFILE_VERSION_MISMATCH:
+										cem_add_to_log("Cannot reload profile, version mismatch.",J_LOG_DEBUG);
+										break;
+									case PROFILE_RELOAD_FAILED:
+										cem_add_to_log("Cannot reload profile",J_LOG_DEBUG);
+										break;
+									case PROFILE_RELOAD_FAILED_NOT_AUTHENTICATED:
+										cem_add_to_log("Cannot reload profile, not authenticated.",J_LOG_DEBUG);
+										break;
+									default:
+										break;
+								}
 							}
 						}
 						
