@@ -228,6 +228,7 @@ typedef struct {
 	guint profile_request_timeout_sid;
 	guint teacher_profile_requests;
 	gboolean waiting_for_teacher;
+	gboolean waiting_profile_from_teacher;
 	gchar* username_to_login;
 
 	gems_teacher_connection* teacher_connection;
@@ -240,7 +241,7 @@ typedef struct {
 /* Generic GEMS message */
 typedef struct {
 	gchar* message;
-	gint32 length;
+	guint32 length;
 } gems_message;
 
 
@@ -256,20 +257,20 @@ void gems_connection_add_16(gems_connection* element, guint16 value);
 void gems_connection_add_32(gems_connection* element, guint32 value);
 void gems_connection_add_64(gems_connection* element, guint64 value);
 void gems_connection_add_float(gems_connection* element, gfloat value);
-void gems_connection_add_char(gems_connection* element, gchar* value, gint length, gboolean pad);
+void gems_connection_add_char(gems_connection* element, gchar* value, guint length, gboolean pad);
 void gems_connection_add_padding(gems_connection* element);
-void gems_connection_add_data(gems_connection* element, gchar* data, gint length);
-guint16 gems_connection_get_16(gems_connection* element, gint from);
-guint32 gems_connection_get_32(gems_connection* element, gint from);
-guint64 gems_connection_get_64(gems_connection* element, gint from);
-gfloat gems_connection_get_float(gems_connection* element, gint from);
-gfloat gems_connection_get_float_for_localization(gems_connection* element, gint from);
-gchar* gems_connection_get_char(gems_connection* element, gint from);
-gchar* gems_connection_get_data(gems_connection* element, gint from, gint length);
+void gems_connection_add_data(gems_connection* element, gchar* data, guint length);
+guint16 gems_connection_get_16(gems_connection* element, guint from);
+guint32 gems_connection_get_32(gems_connection* element, guint from);
+guint64 gems_connection_get_64(gems_connection* element, guint from);
+gfloat gems_connection_get_float(gems_connection* element, guint from);
+gfloat gems_connection_get_float_for_localization(gems_connection* element, guint from);
+gchar* gems_connection_get_char(gems_connection* element, guint from);
+gchar* gems_connection_get_data(gems_connection* element, guint from, guint length);
 
-void gems_connection_set_content(gems_connection* element, gchar* newcontent, gint length);
+void gems_connection_set_content(gems_connection* element, gchar* newcontent, guint length);
 
-gint gems_connection_partial_data_amount(gems_connection* element);
+guint gems_connection_partial_data_amount(gems_connection* element);
 
 void gems_connection_localize_data_in_buffer(gems_connection* element);
 
