@@ -44,14 +44,20 @@ void gems_erase_newline(gchar* c);
  */
 gboolean gems_check_illegal_characters(gchar* data);
 
-/* Returns a list of profiles saved on disk
+/* Returns a list of profiles saved on disk, use gems_free_list_saved_profiles()
+ * to free if necessary - the list is free'd when cleaning up GEMS.
  *
  * Param:
  *  count - will contain the count of profiles found after returning
  * Returns:
- *  a list of profile names as double pointer, use g_strfreev() to free
+ *  a list of profile names as double pointer
  *  NULL when errors accessing directory
  */
 gchar** gems_list_saved_profiles(guint* count);
 
+/* Free the list of saved profiles if it exists */
+void gems_free_list_saved_profiles();
+
+gboolean gems_check_profile_version(gchar* filename);
+
 #endif
